import sys

import rocker
from rocker.core import list_plugins
from rocker.core import pull_image
from rocker.core import DockerImageGenerator


def mcmillan():
    print("Launching McMillan Airfield")
    run_drone_demo('roslaunch sitl_launcher demo.launch gui:=false sitl_world:=mcmillan')

def yosemite():
    print("Launching Yosemite Valley")
    run_drone_demo('roslaunch sitl_launcher demo.launch gui:=false sitl_world:=yosemite')


def run_drone_demo(command):
    plugins = list_plugins()
    base_image = 'tfoote/drone_demo'
    desired_plugins = ['nvidia', 'pulse', 'user', 'home', 'x11']
    active_extensions = [e() for e in plugins.values() if e.get_name() in desired_plugins]
    pull_image(base_image)
    dig = DockerImageGenerator(active_extensions, {}, base_image)
    if dig.build() != 0:
        print ("Failed to build")
        sys.exit(1)
    if dig.run(command) != 0:
        print ("Failed to run")
        sys.exit(1)



#!/usr/bin/env python3

from setuptools import setup

install_requires = [
    'rocker',
]

kwargs = {
    'name': 'px4sitl',
    'version': '0.0.2',
    'packages': ['px4sitl'],
    'package_dir': {'': 'src'},
    # 'package_data': {'rocker': ['templates/*.em']},
    'entry_points': {
        'console_scripts': [
            'mcmillan_px4sitl = px4sitl.cli:mcmillan',
            'yosemite_px4sitl = px4sitl.cli:yosemite',
	    ],
	},
    'author': 'Tully Foote',
    'author_email': 'tfoote@osrfoundation.org',
    'keywords': ['PX4','Gazebo', 'SITL'],
    'classifiers': [
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: Apache Software License'
    ],
    'data_files': [
        ('share/applications', [
            'data/org.osrfoundation.mcmillan_sitl.desktop',
            'data/org.osrfoundation.yosemite_sitl.desktop']),
    ],
    'description': 'Entrypoints to launch SITL based operator training',
    'long_description': 'Entrypoints to launch SITL based operator training',
    'license': 'Apache License 2.0',
    'python_requires': '>=3.0',

    'install_requires': install_requires,
    'url': 'https://github.com/tfoote/px4sitl',
    'zip_safe': False,
}

setup(**kwargs)

